% Generated by roxygen2 (4.0.2): do not edit by hand
\name{tau-utils}
\alias{check_tau}
\alias{complete_tau}
\alias{get_initial_tau}
\alias{tau-utils}
\alias{tau2theta}
\alias{tau2type}
\title{Utilities for transformation vector tau}
\usage{
check_tau(tau)

complete_tau(tau, type = tau2type(tau))

get_initial_tau(y, type = c("h", "hh", "s"), location.family = TRUE)

tau2theta(tau, beta)

tau2type(tau)
}
\arguments{
\item{tau}{named vector \eqn{\tau} which defines the variable transformation. Must have at least
\code{'mu_x'} and \code{'sigma_x'} element; see \code{\link{complete_tau}} for details.}

\item{type}{type of Lambert W \eqn{\times} F distribution: skewed \code{"s"};
heavy-tail \code{"h"}; or skewed heavy-tail \code{"hh"}.}

\item{y}{a numeric vector of real values (the observed data).}

\item{location.family}{logical; if \code{FALSE} it sets \code{mu_x} to 0 and only estimates
\code{sigma_x}; if \code{TRUE} (default), it estimates \code{mu_x} as well.}

\item{beta}{vector; parameter \eqn{\boldsymbol \beta} of the input distribution.
See \code{\link{check_beta}} on how to specify \code{beta} for each distribution.}
}
\value{
\code{check_tau} throws an error if \eqn{\tau} does not define a proper transformation.

\code{complete_tau} returns a named numeric vector.

\code{get_initial_tau} returns a named numeric vector.

\code{tau2theta} returns a list with entries \code{alpha}, \code{beta}, \code{gamma},
and \code{delta}.

\code{tau2type} returns a string: either \code{"s"}, \code{"h"}, or \code{"hh"}.
}
\description{
All functions here are for the transformation parameter
\eqn{\tau = (\mu_x, \sigma_x, \gamma, \delta, \alpha)}.

\code{check_tau} checks if \eqn{\tau} is correctly specified (correct names, non-negativity
constraints, etc.)

\code{complete_tau} completes missing values so users don't have to specify every element of
\eqn{\tau}
explicitly.  Mean \code{'mu_x'} and standard deviation \code{'sigma_x'} must be specified, but
\code{alpha = 1}, \code{gamma = 0}, and \code{delta = 0} will be set automatically if missing.

\code{get_initial_tau} provides starting estimates for \eqn{\tau}.

\code{tau2theta} converts \eqn{\tau} to the parameter list \eqn{\theta}
(inverse of \code{\link{theta2tau}}).

\code{tau2type} guesses the type (\code{'s'}, \code{'h'}, \code{'hh'}) from the names
of \code{tau} vector; thus make sure \code{tau} is named correctly.
}
\keyword{math}
\keyword{utilities}

